math.infix.ops


&clj

source

**clj

(** x__1665 y__1666)
source

<<clj

source

>>clj

source

>>>clj

source

absclj

(abs x__1650)
source

acosclj

(acos x__1681)
source

acotclj

(acot value)

compute arccotangent, given the number, returns the arccotangent in radians

compute arccotangent, given the number, returns the arccotangent in radians
sourceraw docstring

acscclj

(acsc value)

compute arccosecant, given the number, returns the arccosecant in radians

compute arccosecant, given the number, returns the arccosecant in radians
sourceraw docstring

asecclj

(asec value)

compute arcsecant, given the number, returns the arcsecant in radians

compute arcsecant, given the number, returns the arcsecant in radians
sourceraw docstring

asinclj

(asin x__1679)
source

atanclj

(atan x__1683)
source

atan2clj

(atan2 x__1685 y__1686)
source

cosclj

(cos x__1675)
source

coshclj

(cosh x__1690)
source

cotclj

(cot θ)

compute cotangent, given the angle in radians

compute cotangent, given the angle in radians
sourceraw docstring

cscclj

(csc θ)

compute cosecant, given the angle in radians

compute cosecant, given the angle in radians
sourceraw docstring

defbinarycljmacro

(defbinary func-name & [alias])

helper for java.lang.Math binary functions

helper for `java.lang.Math` binary functions
sourceraw docstring

defunarycljmacro

(defunary func-name & [alias])

helper for java.lang.Math unary functions

helper for `java.lang.Math` unary functions
sourceraw docstring

divideclj

(divide a b)

computes the divisor with infinity

computes the divisor with infinity
sourceraw docstring

eclj

source

expclj

(exp x__1658)
source

factclj

(fact n)

computes the factorial

computes the factorial
sourceraw docstring

gcdclj

(gcd a b)

computes the greatest common denominator

computes the greatest common denominator
sourceraw docstring

lcmclj

(lcm a b)

computes the lowest common multiple

computes the lowest common multiple
sourceraw docstring

logclj

(log x__1660)
source

piclj

source

powclj

(pow x__1662 y__1663)
source

productclj

source

rootclj

(root a b)

computes the nth root

computes the nth root
sourceraw docstring

secclj

(sec θ)

compute secant, given the angle in radians

compute secant, given the angle in radians
sourceraw docstring

signumclj

(signum x__1652)
source

sinclj

(sin x__1673)
source

sinhclj

(sinh x__1688)
source

sqrtclj

(sqrt x__1654)
source

sumclj

source

tanclj

(tan x__1677)
source

tanhclj

(tanh x__1692)
source

|clj

source

¬clj

source

÷clj

source

πclj

source

φclj

source

clj

(√ x__1656)
source

cljdoc builds & hosts documentation for Clojure/Script libraries