(acot value)compute arccotangent, given the number, returns the arccotangent in radians
compute arccotangent, given the number, returns the arccotangent in radians
(acsc value)compute arccosecant, given the number, returns the arccosecant in radians
compute arccosecant, given the number, returns the arccosecant in radians
(asec value)compute arcsecant, given the number, returns the arcsecant in radians
compute arcsecant, given the number, returns the arcsecant in radians
(cot θ)compute cotangent, given the angle in radians
compute cotangent, given the angle in radians
(csc θ)compute cosecant, given the angle in radians
compute cosecant, given the angle in radians
(defbinary func-name & [alias])helper for java.lang.Math binary functions
helper for `java.lang.Math` binary functions
(defunary func-name & [alias])helper for java.lang.Math unary functions
helper for `java.lang.Math` unary functions
(divide a b)computes the divisor with infinity
computes the divisor with infinity
(gcd a b)computes the greatest common denominator
computes the greatest common denominator
(lcm a b)computes the lowest common multiple
computes the lowest common multiple
(sec θ)compute secant, given the angle in radians
compute secant, given the angle in radians
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |